@@ -1,4 +1,4 @@
-from .base_functions import entity_list, nest
+from .base_functions import entity_list, nest, check_output_channel
 from .set_block import set_block, meta_set_block
 from .set_image import set_image, meta_set_image, print_palette
 from .set_text import set_text, meta_set_text
