@@ -24,15 +24,19 @@ def meta_set_text(
     palette: list,
     style: str,
     orientation: str,
-    replace: BlockHandler,
+    replace: Union[bool, None],
     scale: int,
-    filler: Block,
+    filler: Union[Block, None],
+    namespace: bool,
 ) -> dict:
 
-    handler = BlockHandler("replace" if replace else "keep")
-
+    if replace is not None:
+      handler = BlockHandler("replace" if replace else "keep")
+    else:
+      handler = None
+    
     offset = 0
-    instructions = {"list": [], "zone": None}
+    instructions = {"cmds": [], "zone": None}
 
     # Can't use enumerate(message) because I don't want
     # to count spaces
@@ -102,10 +106,16 @@ def meta_set_text(
                 # And finally, this is the part where the block is set
                 # depending on whether a scale was specified or not
                 if scale == 0:
+                      
                     block = fetch_block(digit, orientation, palette[mod], filler)
 
-                    cmd = meta_set_block(new_coords, block, handler)
-                    instructions["list"].append(cmd)
+                    if block:
+                      cmd = meta_set_block(new_coords, block, handler)
+                      
+                      if not namespace:
+                        cmd = cmd.replace("minecraft:", "")
+                        
+                      instructions["cmds"].append(cmd)
 
                 # In case it was, it creates "zones" instead
                 # of placing blocks
@@ -127,7 +137,7 @@ def meta_set_text(
                             )
 
                         cmd = meta_set_zone(zone["coords"], block, handler)
-                        instructions["list"].append(cmd)
+                        instructions["cmds"].append(cmd)
 
             # After a line has been printed, the Y level is increased
             y += 1 + scale
@@ -166,7 +176,8 @@ def set_text(
     replace: bool = True,
     scale: int = 0,
     filler: Union[Block, str] = "air",
-) -> Zone:
+    namespace: bool = True,
+) -> dict:
 
     """
     Returns a Zone representing the area used by the text
@@ -215,13 +226,20 @@ def set_text(
         raise ValueError(f"Orientation must be either north or west for set_text()")"""
 
     instructions = meta_set_text(
-        message, coords, palette, style, orientation, replace, scale, filler
+        message, coords, palette, style, orientation, replace, scale, filler, namespace
     )
 
-    for line in instructions["list"]:
-        post(line)
+    status = {
+      "cmd": [],
+      "zone": instructions["zone"]
+    }
+    
+    for cmd in instructions["cmds"]:
+        ret = post(cmd)
+        if ret and ret != '':
+          status['cmd'].append(ret)
 
-    return instructions["zone"]
+    return status
 
 
 def construct_zones(coords: BlockCoordinates, digit: str, scale: int) -> list:
